//
//  SkitchExportFormat.h
//  CoreSkitch
//
//  Created by Josef W. Wankerl on 4/1/13.
//  Copyright 2014 Evernote Corporation. All rights reserved.
//

#import <Foundation/Foundation.h>

/**
	\brief Object to determine which format to use for the export of a Skitch document.
	\details The UTI and also any other special modifiers are encapsulated into one area to allow for easier
		user interface displays of export formats.
*/

@interface SkitchExportFormat : NSObject <NSCopying>

/**
	\brief Returns the universal type identifier of the export format.
	\see isPDFWithSummary
	\see isDOMEmbedded
*/
@property(nonatomic, readonly) CFStringRef uti;

/**
	\brief Returns the localized description of the export format.
*/
@property(nonatomic, readonly) NSString *formatTitle;

/**
	\brief Returns the file extension used by the export format.
*/
@property(nonatomic, readonly) NSString *fileExtension;

/**
	\brief Returns an identifier that completely identifies the export format.
	\details The export format identifier should never be displayed to the user.
		Only use the format identifier to save and restore the last used format identifier.
*/
@property(nonatomic, readonly) NSString *formatIdentifier;

/**
	\brief Returns whether or not the export format is the specialized PDF With Summary format.
*/
@property(nonatomic, assign) BOOL isPDFWithSummary;

/**
	\brief Returns whether or not the export format is a specialized Rich Skitch document format.
	\details Only PNG, JPG, and PDF files are eligable to have an embedded DOM.
*/
@property(nonatomic, assign) BOOL isDOMEmbedded;

/**
	\brief Returns the format identifier for the specialized PDF With Summary format.
	\param isDOMEmbedded YES if the PDF format identifier should specify an embedded DOM; NO if the PDF format should specify a flattened PDF.
	\return The format identifier for a PDF file with summary.
*/
+ (NSString *)pdfWithSummaryFormatIdentifierWithDOMEmbedded:(BOOL)isDOMEmbedded;

/**
	\brief Returns a format identifier for a specialized Rich Skitch document format.
	\details The only valid parameters for uti are kUTTypePNG, kUTTypeJPEG, and kUTTypePDF.
	\param uti The bitmap universal type identifier to make a Rich format identifier from.
	\return The format identifier for a PNG, JPG, or PDF file with embedded DOM.
*/
+ (NSString *)embeddedDOMFormatIdentifierFromUTI:(CFStringRef)uti;

/**
	\brief Creates a SkitchExportFormat instance for the given universal type identifier.
	\details This is the designated initializer.
	\param uti The universal type identifier to make an export format for.
	\return An instance of SkitchExportFormat.
*/
- (instancetype)initWithUTI:(CFStringRef)uti;

/**
	\brief Creates a SkitchExportFormat instance for the given format identifier.
	\details This decodes the format identifier and creates a SkitchExportFormat instance.
	\param formatIdentifier The format identifier to make an export format from.
	\return An instance of SkitchExportFormat.
*/
- (instancetype)initWithFormatIdentifier:(NSString *)formatIdentifier;

/**
	\brief Tests to see if the receiver's format identifier matches the given format identifier.
	\details This is an easy way to test to see if the receiver is of the same type as a saved format identifier.
	\param formatIdentifier The format identifier to test.
	\return YES if the receiver is of the same type as the given formatIdentifier; otherwise NO.
*/
- (BOOL)isEqualToFormatIdentifier:(NSString *)formatIdentifier;

@end
